@@ -1,6 +1,3 @@
-/*
- * $Id: PgDiffIndexes.java 94 2008-09-30 11:07:28Z fordfrog $
- */
 package cz.startnet.utils.pgdiff;
 
 import cz.startnet.utils.pgdiff.schema.PgIndex;
@@ -16,7 +13,6 @@ import java.util.List;
  * Diffs indexes.
  *
  * @author fordfrog
- * @version $Id: PgDiffIndexes.java 94 2008-09-30 11:07:28Z fordfrog $
  */
 public class PgDiffIndexes {
 
@@ -28,19 +24,17 @@ public class PgDiffIndexes {
     }
 
     /**
-     * Outputs commands for differences in indexes.
+     * Outputs commands for creation of new indexes.
      *
      * @param writer writer the output should be written to
      * @param arguments object containing arguments settings
      * @param oldSchema original schema
      * @param newSchema new schema
      */
-    public static void diffIndexes(
-            final PrintWriter writer,
-            final PgDiffArguments arguments,
-            final PgSchema oldSchema,
+    public static void createIndexes(final PrintWriter writer,
+            final PgDiffArguments arguments, final PgSchema oldSchema,
             final PgSchema newSchema) {
-        for (PgTable newTable : newSchema.getTables()) {
+        for (final PgTable newTable : newSchema.getTables()) {
             final String newTableName = newTable.getName();
             final PgTable oldTable;
 
@@ -50,12 +44,6 @@ public class PgDiffIndexes {
                 oldTable = oldSchema.getTable(newTableName);
             }
 
-            // Drop indexes that do not exist in new schema or are modified
-            for (PgIndex index : getDropIndexes(oldTable, newTable)) {
-                writer.println();
-                writer.println(index.getDropSQL(arguments.isQuoteNames()));
-            }
-
             // Add new indexes
             if (oldSchema == null) {
                 for (PgIndex index : newTable.getIndexes()) {
@@ -65,8 +53,7 @@ public class PgDiffIndexes {
                 }
             } else {
                 for (PgIndex index : getNewIndexes(
-                        oldSchema.getTable(newTableName),
-                        newTable)) {
+                        oldSchema.getTable(newTableName), newTable)) {
                     writer.println();
                     writer.println(
                             index.getCreationSQL(arguments.isQuoteNames()));
@@ -75,6 +62,35 @@ public class PgDiffIndexes {
         }
     }
 
+    /**
+     * Outputs commands for dropping indexes that exist no more.
+     *
+     * @param writer writer the output should be written to
+     * @param arguments object containing arguments settings
+     * @param oldSchema original schema
+     * @param newSchema new schema
+     */
+    public static void dropIndexes(final PrintWriter writer,
+            final PgDiffArguments arguments, final PgSchema oldSchema,
+            final PgSchema newSchema) {
+        for (final PgTable newTable : newSchema.getTables()) {
+            final String newTableName = newTable.getName();
+            final PgTable oldTable;
+
+            if (oldSchema == null) {
+                oldTable = null;
+            } else {
+                oldTable = oldSchema.getTable(newTableName);
+            }
+
+            // Drop indexes that do not exist in new schema or are modified
+            for (final PgIndex index : getDropIndexes(oldTable, newTable)) {
+                writer.println();
+                writer.println(index.getDropSQL(arguments.isQuoteNames()));
+            }
+        }
+    }
+
     /**
      * Returns list of indexes that should be dropped.
      *
@@ -86,15 +102,14 @@ public class PgDiffIndexes {
      * @todo Indexes that are depending on a removed field should not be added
      *       to drop because they are already removed.
      */
-    private static List<PgIndex> getDropIndexes(
-            final PgTable oldTable,
+    private static List<PgIndex> getDropIndexes(final PgTable oldTable,
             final PgTable newTable) {
         final List<PgIndex> list = new ArrayList<PgIndex>();
 
         if ((newTable != null) && (oldTable != null)) {
             for (final PgIndex index : oldTable.getIndexes()) {
-                if (!newTable.containsIndex(index.getName()) || !newTable.
-                        getIndex(index.getName()).equals(index)) {
+                if (!newTable.containsIndex(index.getName())
+                        || !newTable.getIndex(index.getName()).equals(index)) {
                     list.add(index);
                 }
             }
@@ -111,8 +126,7 @@ public class PgDiffIndexes {
      *
      * @return list of indexes that should be added
      */
-    private static List<PgIndex> getNewIndexes(
-            final PgTable oldTable,
+    private static List<PgIndex> getNewIndexes(final PgTable oldTable,
             final PgTable newTable) {
         final List<PgIndex> list = new ArrayList<PgIndex>();
 
@@ -123,9 +137,9 @@ public class PgDiffIndexes {
                 }
             } else {
                 for (final PgIndex index : newTable.getIndexes()) {
-                    if (!oldTable.containsIndex(index.getName()) || !oldTable.
-                            getIndex(index.getName()).equals(
-                            index)) {
+                    if (!oldTable.containsIndex(index.getName())
+                            || !oldTable.getIndex(index.getName()).
+                            equals(index)) {
                         list.add(index);
                     }
                 }
