@@ -1,6 +1,3 @@
-/*
- * $Id: PgDiffTables.java 94 2008-09-30 11:07:28Z fordfrog $
- */
 package cz.startnet.utils.pgdiff;
 
 import cz.startnet.utils.pgdiff.schema.PgColumn;
@@ -19,7 +16,6 @@ import java.util.Map;
  * Diffs tables.
  *
  * @author fordfrog
- * @version $Id: PgDiffTables.java 94 2008-09-30 11:07:28Z fordfrog $
  */
 public class PgDiffTables {
 
@@ -31,19 +27,17 @@ public class PgDiffTables {
     }
 
     /**
-     * Generates and outputs CLUSTER specific DDL if appropriate.
+     * Outputs commands for creation of clusters.
      *
      * @param writer writer the output should be written to
      * @param arguments object containing arguments settings
      * @param oldSchema original schema
      * @param newSchema new schema
      */
-    public static void diffClusters(
-            final PrintWriter writer,
-            final PgDiffArguments arguments,
-            final PgSchema oldSchema,
+    public static void dropClusters(final PrintWriter writer,
+            final PgDiffArguments arguments, final PgSchema oldSchema,
             final PgSchema newSchema) {
-        for (PgTable newTable : newSchema.getTables()) {
+        for (final PgTable newTable : newSchema.getTables()) {
             final PgTable oldTable;
 
             if (oldSchema == null) {
@@ -62,53 +56,76 @@ public class PgDiffTables {
 
             final String newCluster = newTable.getClusterIndexName();
 
-            if (((oldCluster == null) && (newCluster != null)) ||
-                    ((oldCluster != null) && (newCluster != null) &&
-                    (newCluster.compareTo(oldCluster) != 0))) {
+            if ((oldCluster != null) && (newCluster == null)
+                    && newTable.containsIndex(oldCluster)) {
                 writer.println();
                 writer.print("ALTER TABLE ");
-                writer.print(
-                        PgDiffUtils.getQuotedName(
-                        newTable.getName(),
-                        arguments.isQuoteNames()));
-                writer.print(" CLUSTER ON ");
-                writer.print(
-                        PgDiffUtils.getQuotedName(
-                        newCluster,
-                        arguments.isQuoteNames()));
-                writer.println(';');
-            } else if ((oldCluster != null) && (newCluster == null) && newTable.
-                    containsIndex(oldCluster)) {
-                writer.println();
-                writer.print("ALTER TABLE ");
-                writer.print(
-                        PgDiffUtils.getQuotedName(
-                        newTable.getName(),
-                        arguments.isQuoteNames()));
+                writer.print(PgDiffUtils.getQuotedName(
+                        newTable.getName(), arguments.isQuoteNames()));
                 writer.println(" SET WITHOUT CLUSTER;");
             }
         }
     }
 
     /**
-     * Creates diff of tables.
+     * Outputs commands for dropping of clusters.
      *
      * @param writer writer the output should be written to
      * @param arguments object containing arguments settings
      * @param oldSchema original schema
      * @param newSchema new schema
      */
-    public static void diffTables(
-            final PrintWriter writer,
-            final PgDiffArguments arguments,
-            final PgSchema oldSchema,
+    public static void createClusters(final PrintWriter writer,
+            final PgDiffArguments arguments, final PgSchema oldSchema,
             final PgSchema newSchema) {
-        dropTables(writer, arguments, oldSchema, newSchema);
-        createTables(writer, arguments, oldSchema, newSchema);
+        for (final PgTable newTable : newSchema.getTables()) {
+            final PgTable oldTable;
 
-        for (PgTable newTable : newSchema.getTables()) {
-            if ((oldSchema == null) || !oldSchema.containsTable(
-                    newTable.getName())) {
+            if (oldSchema == null) {
+                oldTable = null;
+            } else {
+                oldTable = oldSchema.getTable(newTable.getName());
+            }
+
+            final String oldCluster;
+
+            if (oldTable == null) {
+                oldCluster = null;
+            } else {
+                oldCluster = oldTable.getClusterIndexName();
+            }
+
+            final String newCluster = newTable.getClusterIndexName();
+
+            if (((oldCluster == null) && (newCluster != null))
+                    || ((oldCluster != null) && (newCluster != null)
+                    && (newCluster.compareTo(oldCluster) != 0))) {
+                writer.println();
+                writer.print("ALTER TABLE ");
+                writer.print(PgDiffUtils.getQuotedName(
+                        newTable.getName(), arguments.isQuoteNames()));
+                writer.print(" CLUSTER ON ");
+                writer.print(PgDiffUtils.getQuotedName(
+                        newCluster, arguments.isQuoteNames()));
+                writer.println(';');
+            }
+        }
+    }
+
+    /**
+     * Outputs commands for altering tables.
+     *
+     * @param writer writer the output should be written to
+     * @param arguments object containing arguments settings
+     * @param oldSchema original schema
+     * @param newSchema new schema
+     */
+    public static void alterTables(final PrintWriter writer,
+            final PgDiffArguments arguments, final PgSchema oldSchema,
+            final PgSchema newSchema) {
+        for (final PgTable newTable : newSchema.getTables()) {
+            if ((oldSchema == null)
+                    || !oldSchema.containsTable(newTable.getName())) {
                 continue;
             }
 
@@ -128,14 +145,12 @@ public class PgDiffTables {
      * @param oldTable original table
      * @param newTable new table
      */
-    private static void addAlterStatistics(
-            final PrintWriter writer,
-            final PgDiffArguments arguments,
-            final PgTable oldTable,
+    private static void addAlterStatistics(final PrintWriter writer,
+            final PgDiffArguments arguments, final PgTable oldTable,
             final PgTable newTable) {
         final Map<String, Integer> stats = new HashMap<String, Integer>();
 
-        for (PgColumn newColumn : newTable.getColumns()) {
+        for (final PgColumn newColumn : newTable.getColumns()) {
             final PgColumn oldColumn = oldTable.getColumn(newColumn.getName());
 
             if (oldColumn != null) {
@@ -143,8 +158,8 @@ public class PgDiffTables {
                 final Integer newStat = newColumn.getStatistics();
                 Integer newStatValue = null;
 
-                if ((newStat != null) && ((oldStat == null) || !newStat.equals(
-                        oldStat))) {
+                if ((newStat != null) && ((oldStat == null)
+                        || !newStat.equals(oldStat))) {
                     newStatValue = newStat;
                 } else if ((oldStat != null) && (newStat == null)) {
                     newStatValue = Integer.valueOf(-1);
@@ -156,18 +171,14 @@ public class PgDiffTables {
             }
         }
 
-        for (Map.Entry<String, Integer> entry : stats.entrySet()) {
+        for (final Map.Entry<String, Integer> entry : stats.entrySet()) {
             writer.println();
             writer.print("ALTER TABLE ONLY ");
-            writer.print(
-                    PgDiffUtils.getQuotedName(
-                    newTable.getName(),
-                    arguments.isQuoteNames()));
+            writer.print(PgDiffUtils.getQuotedName(
+                    newTable.getName(), arguments.isQuoteNames()));
             writer.print(" ALTER COLUMN ");
-            writer.print(
-                    PgDiffUtils.getQuotedName(
-                    entry.getKey(),
-                    arguments.isQuoteNames()));
+            writer.print(PgDiffUtils.getQuotedName(
+                    entry.getKey(), arguments.isQuoteNames()));
             writer.print(" SET STATISTICS ");
             writer.print(entry.getValue());
             writer.println(';');
@@ -185,18 +196,13 @@ public class PgDiffTables {
      * @param dropDefaultsColumns list for storing columns for which default
      *        value should be dropped
      */
-    private static void addCreateTableColumns(
-            final List<String> commands,
-            final PgDiffArguments arguments,
-            final PgTable oldTable,
-            final PgTable newTable,
-            final List<PgColumn> dropDefaultsColumns) {
-        for (PgColumn column : newTable.getColumns()) {
+    private static void addCreateTableColumns(final List<String> commands,
+            final PgDiffArguments arguments, final PgTable oldTable,
+            final PgTable newTable, final List<PgColumn> dropDefaultsColumns) {
+        for (final PgColumn column : newTable.getColumns()) {
             if (!oldTable.containsColumn(column.getName())) {
-                commands.add(
-                        "\tADD COLUMN " + column.getFullDefinition(
-                        arguments.isQuoteNames(),
-                        arguments.isAddDefaults()));
+                commands.add("\tADD COLUMN " + column.getFullDefinition(
+                        arguments.isQuoteNames(), arguments.isAddDefaults()));
 
                 if (arguments.isAddDefaults() && !column.getNullValue()) {
                     dropDefaultsColumns.add(column);
@@ -213,17 +219,13 @@ public class PgDiffTables {
      * @param oldTable original table
      * @param newTable new table
      */
-    private static void addDropTableColumns(
-            final List<String> commands,
-            final PgDiffArguments arguments,
-            final PgTable oldTable,
+    private static void addDropTableColumns(final List<String> commands,
+            final PgDiffArguments arguments, final PgTable oldTable,
             final PgTable newTable) {
-        for (PgColumn column : oldTable.getColumns()) {
+        for (final PgColumn column : oldTable.getColumns()) {
             if (!newTable.containsColumn(column.getName())) {
-                commands.add(
-                        "\tDROP COLUMN " + PgDiffUtils.getQuotedName(
-                        column.getName(),
-                        arguments.isQuoteNames()));
+                commands.add("\tDROP COLUMN " + PgDiffUtils.getQuotedName(
+                        column.getName(), arguments.isQuoteNames()));
             }
         }
     }
@@ -239,54 +241,45 @@ public class PgDiffTables {
      * @param dropDefaultsColumns list for storing columns for which default
      *        value should be dropped
      */
-    private static void addModifyTableColumns(
-            final List<String> commands,
-            final PgDiffArguments arguments,
-            final PgTable oldTable,
-            final PgTable newTable,
-            final List<PgColumn> dropDefaultsColumns) {
-        for (PgColumn newColumn : newTable.getColumns()) {
+    private static void addModifyTableColumns(final List<String> commands,
+            final PgDiffArguments arguments, final PgTable oldTable,
+            final PgTable newTable, final List<PgColumn> dropDefaultsColumns) {
+        for (final PgColumn newColumn : newTable.getColumns()) {
             if (!oldTable.containsColumn(newColumn.getName())) {
                 continue;
             }
 
             final PgColumn oldColumn = oldTable.getColumn(newColumn.getName());
-            final String newColumnName =
-                    PgDiffUtils.getQuotedName(
-                    newColumn.getName(),
-                    arguments.isQuoteNames());
+            final String newColumnName = PgDiffUtils.getQuotedName(
+                    newColumn.getName(), arguments.isQuoteNames());
 
             if (!oldColumn.getType().equals(newColumn.getType())) {
-                commands.add(
-                        "\tALTER COLUMN " + newColumnName + " TYPE " +
-                        newColumn.getType() + " /* TYPE change - table: " +
-                        newTable.getName() + " original: " +
-                        oldColumn.getType() + " new: " + newColumn.getType() +
-                        " */");
+                commands.add("\tALTER COLUMN " + newColumnName + " TYPE "
+                        + newColumn.getType() + " /* TYPE change - table: "
+                        + newTable.getName() + " original: "
+                        + oldColumn.getType() + " new: " + newColumn.getType()
+                        + " */");
             }
 
-            final String oldDefault =
-                    (oldColumn.getDefaultValue() == null) ? ""
+            final String oldDefault = (oldColumn.getDefaultValue() == null) ? ""
                     : oldColumn.getDefaultValue();
-            final String newDefault =
-                    (newColumn.getDefaultValue() == null) ? ""
+            final String newDefault = (newColumn.getDefaultValue() == null) ? ""
                     : newColumn.getDefaultValue();
 
             if (!oldDefault.equals(newDefault)) {
                 if (newDefault.length() == 0) {
-                    commands.add(
-                            "\tALTER COLUMN " + newColumnName + " DROP DEFAULT");
+                    commands.add("\tALTER COLUMN " + newColumnName
+                            + " DROP DEFAULT");
                 } else {
-                    commands.add(
-                            "\tALTER COLUMN " + newColumnName + " SET DEFAULT " +
-                            newDefault);
+                    commands.add("\tALTER COLUMN " + newColumnName
+                            + " SET DEFAULT " + newDefault);
                 }
             }
 
             if (oldColumn.getNullValue() != newColumn.getNullValue()) {
                 if (newColumn.getNullValue()) {
-                    commands.add(
-                            "\tALTER COLUMN " + newColumnName + " DROP NOT NULL");
+                    commands.add("\tALTER COLUMN " + newColumnName
+                            + " DROP NOT NULL");
                 } else {
                     if (arguments.isAddDefaults()) {
                         final String defaultValue =
@@ -294,15 +287,14 @@ public class PgDiffTables {
                                 newColumn.getType());
 
                         if (defaultValue != null) {
-                            commands.add(
-                                    "\tALTER COLUMN " + newColumnName +
-                                    " SET DEFAULT " + defaultValue);
+                            commands.add("\tALTER COLUMN " + newColumnName
+                                    + " SET DEFAULT " + defaultValue);
                             dropDefaultsColumns.add(newColumn);
                         }
                     }
 
-                    commands.add(
-                            "\tALTER COLUMN " + newColumnName + " SET NOT NULL");
+                    commands.add("\tALTER COLUMN " + newColumnName
+                            + " SET NOT NULL");
                 }
             }
         }
@@ -317,39 +309,34 @@ public class PgDiffTables {
      * @param oldTable original table
      * @param newTable new table
      */
-    private static void checkInherits(
-            final PrintWriter writer,
-            final PgDiffArguments arguments,
-            final PgTable oldTable,
+    private static void checkInherits(final PrintWriter writer,
+            final PgDiffArguments arguments, final PgTable oldTable,
             final PgTable newTable) {
         final String oldInherits = oldTable.getInherits();
         final String newInherits = newTable.getInherits();
 
         if ((oldInherits == null) && (newInherits != null)) {
             writer.println();
-            writer.println(
-                    "Modified INHERITS on TABLE " + PgDiffUtils.getQuotedName(
-                    newTable.getName(),
-                    arguments.isQuoteNames()) +
-                    ": original table doesn't use INHERITS but new table " +
-                    "uses INHERITS " + newTable.getInherits());
+            writer.println("Modified INHERITS on TABLE "
+                    + PgDiffUtils.getQuotedName(
+                    newTable.getName(), arguments.isQuoteNames())
+                    + ": original table doesn't use INHERITS but new table "
+                    + "uses INHERITS " + newTable.getInherits());
         } else if ((oldInherits != null) && (newInherits == null)) {
             writer.println();
-            writer.println(
-                    "Modified INHERITS on TABLE " + PgDiffUtils.getQuotedName(
-                    newTable.getName(),
-                    arguments.isQuoteNames()) +
-                    ": original table uses INHERITS " + oldTable.getInherits() +
-                    " but new table doesn't use INHERITS");
-        } else if ((oldInherits != null) && (newInherits != null) &&
-                !oldInherits.equals(newInherits)) {
+            writer.println("Modified INHERITS on TABLE "
+                    + PgDiffUtils.getQuotedName(
+                    newTable.getName(), arguments.isQuoteNames())
+                    + ": original table uses INHERITS " + oldTable.getInherits()
+                    + " but new table doesn't use INHERITS");
+        } else if ((oldInherits != null) && (newInherits != null)
+                && !oldInherits.equals(newInherits)) {
             writer.println();
-            writer.println(
-                    "Modified INHERITS on TABLE " + PgDiffUtils.getQuotedName(
-                    newTable.getName(),
-                    arguments.isQuoteNames()) +
-                    ": original table uses INHERITS " + oldTable.getInherits() +
-                    " but new table uses INHERITS " + newTable.getInherits());
+            writer.println("Modified INHERITS on TABLE "
+                    + PgDiffUtils.getQuotedName(
+                    newTable.getName(), arguments.isQuoteNames())
+                    + ": original table uses INHERITS " + oldTable.getInherits()
+                    + " but new table uses INHERITS " + newTable.getInherits());
         }
     }
 
@@ -363,26 +350,20 @@ public class PgDiffTables {
      * @param oldTable original table
      * @param newTable new table
      */
-    private static void checkWithOIDS(
-            final PrintWriter writer,
-            final PgDiffArguments arguments,
-            final PgTable oldTable,
+    private static void checkWithOIDS(final PrintWriter writer,
+            final PgDiffArguments arguments, final PgTable oldTable,
             final PgTable newTable) {
         if (oldTable.isWithOIDS() && !newTable.isWithOIDS()) {
             writer.println();
-            writer.println(
-                    "ALTER TABLE " + PgDiffUtils.getQuotedName(
-                    newTable.getName(),
-                    arguments.isQuoteNames()));
+            writer.println("ALTER TABLE " + PgDiffUtils.getQuotedName(
+                    newTable.getName(), arguments.isQuoteNames()));
             writer.println("\tSET WITHOUT OIDS;");
         } else if (!oldTable.isWithOIDS() && newTable.isWithOIDS()) {
             writer.println();
-            writer.println(
-                    "WARNING: Table " + PgDiffUtils.getQuotedName(
-                    newTable.getName(),
-                    arguments.isQuoteNames()) +
-                    " adds WITH OIDS but there is no equivalent command " +
-                    "for adding of OIDS in PostgreSQL");
+            writer.println("WARNING: Table " + PgDiffUtils.getQuotedName(
+                    newTable.getName(), arguments.isQuoteNames())
+                    + " adds WITH OIDS but there is no equivalent command "
+                    + "for adding of OIDS in PostgreSQL");
         }
     }
 
@@ -394,13 +375,12 @@ public class PgDiffTables {
      * @param oldSchema original schema
      * @param newSchema new schema
      */
-    private static void createTables(
-            final PrintWriter writer,
-            final PgDiffArguments arguments,
-            final PgSchema oldSchema,
+    public static void createTables(final PrintWriter writer,
+            final PgDiffArguments arguments, final PgSchema oldSchema,
             final PgSchema newSchema) {
-        for (PgTable table : newSchema.getTables()) {
-            if ((oldSchema == null) || !oldSchema.containsTable(table.getName())) {
+        for (final PgTable table : newSchema.getTables()) {
+            if ((oldSchema == null)
+                    || !oldSchema.containsTable(table.getName())) {
                 writer.println();
                 writer.println(table.getCreationSQL(arguments.isQuoteNames()));
             }
@@ -415,13 +395,11 @@ public class PgDiffTables {
      * @param oldSchema original schema
      * @param newSchema new schema
      */
-    private static void dropTables(
-            final PrintWriter writer,
-            final PgDiffArguments arguments,
-            final PgSchema oldSchema,
+    public static void dropTables(final PrintWriter writer,
+            final PgDiffArguments arguments, final PgSchema oldSchema,
             final PgSchema newSchema) {
         if (oldSchema != null) {
-            for (PgTable table : oldSchema.getTables()) {
+            for (final PgTable table : oldSchema.getTables()) {
                 if (!newSchema.containsTable(table.getName())) {
                     writer.println();
                     writer.println(table.getDropSQL(arguments.isQuoteNames()));
@@ -439,32 +417,20 @@ public class PgDiffTables {
      * @param oldTable original table
      * @param newTable new table
      */
-    private static void updateTableColumns(
-            final PrintWriter writer,
-            final PgDiffArguments arguments,
-            final PgTable oldTable,
+    private static void updateTableColumns(final PrintWriter writer,
+            final PgDiffArguments arguments, final PgTable oldTable,
             final PgTable newTable) {
         final List<String> commands = new ArrayList<String>();
         final List<PgColumn> dropDefaultsColumns = new ArrayList<PgColumn>();
         addDropTableColumns(commands, arguments, oldTable, newTable);
         addCreateTableColumns(
-                commands,
-                arguments,
-                oldTable,
-                newTable,
-                dropDefaultsColumns);
+                commands, arguments, oldTable, newTable, dropDefaultsColumns);
         addModifyTableColumns(
-                commands,
-                arguments,
-                oldTable,
-                newTable,
-                dropDefaultsColumns);
+                commands, arguments, oldTable, newTable, dropDefaultsColumns);
 
         if (commands.size() > 0) {
-            final String quotedTableName =
-                    PgDiffUtils.getQuotedName(
-                    newTable.getName(),
-                    arguments.isQuoteNames());
+            final String quotedTableName = PgDiffUtils.getQuotedName(
+                    newTable.getName(), arguments.isQuoteNames());
             writer.println();
             writer.println("ALTER TABLE " + quotedTableName);
 
@@ -479,8 +445,7 @@ public class PgDiffTables {
 
                 for (int i = 0; i < dropDefaultsColumns.size(); i++) {
                     writer.print("\tALTER COLUMN ");
-                    writer.print(
-                            PgDiffUtils.getQuotedName(
+                    writer.print(PgDiffUtils.getQuotedName(
                             dropDefaultsColumns.get(i).getName(),
                             arguments.isQuoteNames()));
                     writer.print(" DROP DEFAULT");
