@@ -1,15 +1,12 @@
-/*
- * $Id: ParserException.java 80 2007-09-01 20:25:45Z fordfrog $
- */
 package cz.startnet.utils.pgdiff.parsers;
 
 /**
  * Thrown if parsing problem occured.
  *
  * @author fordfrog
- * @version $Id: ParserException.java 80 2007-09-01 20:25:45Z fordfrog $
  */
 public class ParserException extends RuntimeException {
+
     /**
      * Predefined message string that can be used as default exception
      * message with provided parsed line.
@@ -30,7 +27,7 @@ public class ParserException extends RuntimeException {
      *
      * @param msg the detail message
      */
-    public ParserException(String msg) {
+    public ParserException(final String msg) {
         super(msg);
     }
 
@@ -41,7 +38,7 @@ public class ParserException extends RuntimeException {
      * @param msg the detail message
      * @param cause cause of the exception
      */
-    public ParserException(String msg, Throwable cause) {
+    public ParserException(final String msg, final Throwable cause) {
         super(msg, cause);
     }
 }
