@@ -1,6 +1,3 @@
-/*
- * $Id$
- */
 package cz.startnet.utils.pgdiff.parsers;
 
 import org.hamcrest.core.IsEqual;
@@ -11,7 +8,6 @@ import org.junit.Test;
  * Tests {@link ParserUtils}.
  *
  * @author fordfrog
- * @version $Id$
  */
 public class ParserUtilsTest {
 
@@ -23,8 +19,8 @@ public class ParserUtilsTest {
     public void getCommandEndSingleQuotes() {
         final int result =
                 ParserUtils.getCommandEnd(
-                "CREATE TABLE user_preferences (exboxes text " +
-                "DEFAULT '''test1'',''test2'',''test3'',''test4'''::text )",
+                "CREATE TABLE user_preferences (exboxes text "
+                + "DEFAULT '''test1'',''test2'',''test3'',''test4'''::text )",
                 31);
         Assert.assertThat(result, IsEqual.equalTo(100));
     }
